@@ -9,6 +9,7 @@ import (
 	"github.com/dundee/gdu/v5/internal/testapp"
 	"github.com/dundee/gdu/v5/internal/testdir"
 	"github.com/dundee/gdu/v5/pkg/analyze"
+	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
 	"github.com/stretchr/testify/assert"
@@ -19,7 +20,7 @@ func TestShowHelp(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, '?', 0))
 
@@ -31,7 +32,7 @@ func TestCloseHelp(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 	ui.showHelp()
 
 	assert.True(t, ui.pages.HasPage("help"))
@@ -41,12 +42,27 @@ func TestCloseHelp(t *testing.T) {
 	assert.False(t, ui.pages.HasPage("help"))
 }
 
+func TestCloseHelpWithQuestionMark(t *testing.T) {
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
+	ui.showHelp()
+
+	assert.True(t, ui.pages.HasPage("help"))
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, '?', 0))
+
+	assert.False(t, ui.pages.HasPage("help"))
+}
+
 func TestKeyWhileDeleting(t *testing.T) {
 	simScreen := testapp.CreateSimScreen(50, 50)
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 
 	modal := tview.NewModal().SetText("Deleting...")
 	ui.pages.AddPage("deleting", modal, true, true)
@@ -60,7 +76,7 @@ func TestLeftRightKeyWhileConfirm(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 
 	modal := tview.NewModal().SetText("Really?")
 	ui.pages.AddPage("confirm", modal, true, true)
@@ -78,7 +94,7 @@ func TestMoveLeftRight(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
 	assert.Nil(t, err)
@@ -92,29 +108,29 @@ func TestMoveLeftRight(t *testing.T) {
 	ui.table.Select(0, 0)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 
-	assert.Equal(t, "nested", ui.currentDir.Name)
+	assert.Equal(t, "nested", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0)) // try /.. first
 
-	assert.Equal(t, "nested", ui.currentDir.Name)
+	assert.Equal(t, "nested", ui.currentDir.GetName())
 
 	ui.table.Select(1, 0)
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 
-	assert.Equal(t, "subnested", ui.currentDir.Name)
+	assert.Equal(t, "subnested", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyLeft, 'h', 0))
 
-	assert.Equal(t, "nested", ui.currentDir.Name)
+	assert.Equal(t, "nested", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyLeft, 'h', 0))
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyLeft, 'h', 0))
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 }
 
 func TestMoveRightOnDevice(t *testing.T) {
@@ -124,7 +140,7 @@ func TestMoveRightOnDevice(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	ui.SetIgnoreDirPaths([]string{})
@@ -141,7 +157,7 @@ func TestMoveRightOnDevice(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 }
 
 func TestStop(t *testing.T) {
@@ -149,7 +165,7 @@ func TestStop(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(false)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 
 	key := ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'q', 0))
 	assert.Nil(t, key)
@@ -163,7 +179,7 @@ func TestStopWithPrintingPath(t *testing.T) {
 
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
-	ui := CreateUI(app, simScreen, buff, true, true, false)
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
 
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -189,7 +205,7 @@ func TestSpawnShell(t *testing.T) {
 
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
-	ui := CreateUI(app, simScreen, buff, true, true, false)
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
 	var called = false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
@@ -219,7 +235,7 @@ func TestSpawnShellWithoutDir(t *testing.T) {
 
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
-	ui := CreateUI(app, simScreen, buff, true, true, false)
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
 	var called = false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
@@ -241,7 +257,7 @@ func TestSpawnShellWithWrongDir(t *testing.T) {
 
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
-	ui := CreateUI(app, simScreen, buff, true, true, false)
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
 	var called = false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
@@ -266,7 +282,7 @@ func TestSpawnShellWithError(t *testing.T) {
 
 	app := testapp.CreateMockedApp(false)
 	buff := &bytes.Buffer{}
-	ui := CreateUI(app, simScreen, buff, true, true, false)
+	ui := CreateUI(app, simScreen, buff, true, true, false, false, false)
 	var called = false
 	ui.exec = func(argv0 string, argv, envv []string) error {
 		called = true
@@ -288,7 +304,7 @@ func TestShowConfirm(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, true, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -300,7 +316,7 @@ func TestShowConfirm(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.table.Select(1, 0)
 
@@ -314,7 +330,7 @@ func TestDeleteEmpty(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 
 	key := ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'd', 0))
@@ -328,7 +344,7 @@ func TestDelete(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	ui.askBeforeDelete = false
 	err := ui.AnalyzePath("test_dir", nil)
@@ -340,7 +356,7 @@ func TestDelete(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	assert.Equal(t, 1, ui.table.GetRowCount())
 
@@ -364,7 +380,7 @@ func TestDeleteParent(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	ui.askBeforeDelete = false
 	err := ui.AnalyzePath("test_dir", nil)
@@ -376,7 +392,7 @@ func TestDeleteParent(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 	assert.Equal(t, 1, ui.table.GetRowCount())
 
 	ui.table.Select(0, 0)
@@ -394,7 +410,7 @@ func TestEmptyDir(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	ui.askBeforeDelete = false
 	err := ui.AnalyzePath("test_dir", nil)
@@ -406,7 +422,7 @@ func TestEmptyDir(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	assert.Equal(t, 1, ui.table.GetRowCount())
 
@@ -431,7 +447,7 @@ func TestEmptyFile(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	ui.askBeforeDelete = false
 	err := ui.AnalyzePath("test_dir", nil)
@@ -443,7 +459,7 @@ func TestEmptyFile(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	assert.Equal(t, 1, ui.table.GetRowCount())
 
@@ -470,7 +486,7 @@ func TestSortByApparentSize(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -482,7 +498,7 @@ func TestSortByApparentSize(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'a', 0))
 
@@ -494,7 +510,7 @@ func TestShowFileCount(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, false, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -506,7 +522,7 @@ func TestShowFileCount(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'c', 0))
 
@@ -518,7 +534,7 @@ func TestShowFileCountBW(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -530,7 +546,7 @@ func TestShowFileCountBW(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'c', 0))
 
@@ -542,7 +558,7 @@ func TestShowMtime(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, true, false, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -554,7 +570,7 @@ func TestShowMtime(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'm', 0))
 
@@ -566,7 +582,7 @@ func TestShowMtimeBW(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -578,19 +594,44 @@ func TestShowMtimeBW(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'm', 0))
 
 	assert.True(t, ui.showMtime)
 }
 
+func TestShowRelativeBar(t *testing.T) {
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false, false, false)
+	ui.Analyzer = &testanalyze.MockedAnalyzer{}
+	ui.done = make(chan struct{})
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
+		f()
+	}
+
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
+	assert.False(t, ui.ShowRelativeSize)
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'B', 0))
+
+	assert.True(t, ui.ShowRelativeSize)
+}
+
 func TestRescan(t *testing.T) {
 	parentDir := &analyze.Dir{
 		File: &analyze.File{
 			Name: "parent",
 		},
-		Files: make([]analyze.Item, 0, 1),
+		Files: make([]fs.Item, 0, 1),
 	}
 	currentDir := &analyze.Dir{
 		File: &analyze.File{
@@ -603,7 +644,7 @@ func TestRescan(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.currentDir = currentDir
@@ -617,8 +658,8 @@ func TestRescan(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
-	assert.Equal(t, parentDir, ui.currentDir.Parent)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
+	assert.Equal(t, parentDir, ui.currentDir.GetParent())
 
 	assert.Equal(t, 5, ui.table.GetRowCount())
 	assert.Contains(t, ui.table.GetCell(0, 0).Text, "/..")
@@ -630,7 +671,7 @@ func TestSorting(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.Analyzer = &testanalyze.MockedAnalyzer{}
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
@@ -642,7 +683,7 @@ func TestSorting(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 's', 0))
 	assert.Equal(t, "size", ui.sortBy)
@@ -661,7 +702,7 @@ func TestShowFile(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
 	assert.Nil(t, err)
@@ -672,7 +713,7 @@ func TestShowFile(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.table.Select(0, 0)
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
@@ -688,7 +729,7 @@ func TestShowInfoAndMoveAround(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true, false, false, false)
 	ui.done = make(chan struct{})
 	err := ui.AnalyzePath("test_dir", nil)
 	assert.Nil(t, err)
@@ -699,7 +740,7 @@ func TestShowInfoAndMoveAround(t *testing.T) {
 		f()
 	}
 
-	assert.Equal(t, "test_dir", ui.currentDir.Name)
+	assert.Equal(t, "test_dir", ui.currentDir.GetName())
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'i', 0))
@@ -708,6 +749,10 @@ func TestShowInfoAndMoveAround(t *testing.T) {
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'k', 0)) // move up
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'j', 0)) // move down
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'k', 0)) // move up
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, '?', 0)) // does nothing
+
+	assert.True(t, ui.pages.HasPage("info")) // we can still see info page
 
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'q', 0))
 
